#ifndef MAINSCREEN_HPP_INCLUDED
#define MAINSCREEN_HPP_INCLUDED

#include "../../Core/Types/Box.hpp"
#include "../../Core/Types/Tile.hpp"
#include "../../Core/Classes/Character.hpp"
#include <cstdint>
#include <string>
#include <vector>

/** @addtogroup Interfaces
* @{ */
namespace Mainscreen
{
    typedef enum SCREEN_STATE
    {
        LOGIN_SCREEN,
        LOBBY_SCREEN,
        CONNECTING,
        LOADING,
        HOPPING,
        PLAYING
    } SCREEN_STATE;

    typedef enum CROSSHAIR_STATE
    {
        NONE,
        YELLOW,
        RED
    } CROSSHAIR_STATE;

    Mainscreen::SCREEN_STATE GetState();
    Mainscreen::CROSSHAIR_STATE GetCrosshairState();

    bool IsLoggedIn();
    bool IsMoving();
    bool IsAnimating();

    std::string GetUpText();
    bool UpTextContains(const std::string& UpText);
    bool UpTextContains(const std::vector<std::string>& UpTexts);
    bool IsUpText(const std::string& UpText);
    bool IsUpText(const std::vector<std::string>& UpTexts);
    bool WaitIsUpText(std::uint32_t Duration, std::uint32_t Step, const std::string& UpText);
    bool WaitUpTextContains(std::uint32_t Duration, std::uint32_t Step, const std::string& UpText);
    bool WaitUpTextContains(std::uint32_t Duration, std::uint32_t Step, const std::vector<std::string>& UpTexts);
    bool ClickTile(const Tile& T);
}

/** @} */

#endif // MAINSCREEN_HPP_INCLUDED
